@@ -1,10 +1,12 @@
 # -*- coding: utf-8 -*-
-from plone.app.linkintegrity.handlers import referencedRelationship
 from plone.registry.interfaces import IRegistry
 from Products.CMFPlone.interfaces import IEditingSchema
 from zc.relation.interfaces import ICatalog
 from zope.component import getUtility
 from zope.intid.interfaces import IIntIds
+from zope.keyreference.interfaces import NotYet
+
+referencedRelationship = 'isReferencing'
 
 
 def getIncomingLinks(
@@ -63,3 +65,20 @@ def linkintegrity_enabled():
     reg = getUtility(IRegistry)
     editing_settings = reg.forInterface(IEditingSchema, prefix='plone')
     return editing_settings.enable_link_integrity_checks
+
+
+def ensure_intid(obj, intids=None):
+    if intids is None:
+        intids = getUtility(IIntIds)
+    try:
+        obj_id = intids.getId(obj)
+    except KeyError:
+        # In some cases a object is not yet registered by the intid catalog
+        try:
+            obj_id = intids.register(obj)
+        except NotYet:
+            # if we get a NotYet error, the object is not
+            # attached yet and we will need to get links
+            # at a later time when the object has an intid
+            return
+    return obj_id
